##  Overview
The PII change audit report provides a downloadable log of updates to a users' personally identifiable information (PII). This report supports compliance requirements and audit processes by tracking changes to sensitive user attributes such as email addresses and names. It helps answer questions such as:
  * When was a user’s email address modified?
  * Which administrator performed the change?
